[jboss-cvs] JBossAS SVN: r108484 - in trunk/webservices/src: main/java/org/jboss/webservices/integration/deployers and 10 other directories.

jboss-cvs-commits at lists.jboss.org jboss-cvs-commits at lists.jboss.org
Fri Oct 8 03:38:49 EDT 2010


Author: richard.opalka at jboss.com
Date: 2010-10-08 03:38:48 -0400 (Fri, 08 Oct 2010)
New Revision: 108484

Added:
   trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/AbstractDescriptorDeployer.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/JMSDescriptorDeployer.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/deployment/DeploymentModelBuilderJAXWS_JMS.java
Modified:
   trunk/webservices/src/main/java/org/jboss/webservices/integration/config/ServerConfigFactoryImpl.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/config/ServerConfigImpl.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/JAXRPCAppClientClassPathDeployer.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/JAXRPCClientClassPathDeployer.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/JAXRPCEjbClientClassPathDeployer.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/JAXRPCIntegrationClassPathDeployer.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/JAXRPCServerClassPathDeployer.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/JAXRPCServletClientClassPathDeployer.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/SecurityActions.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/WSAspectizedDeployersFactory.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/WSDeploymentAspectDeployer.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/WSDeploymentDeployer.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/WSDescriptorDeployer.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/WSEJBAdapterDeployer.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/WSTypeDeployer.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/deployment/AbstractDeploymentModelBuilder.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/deployment/DeploymentModelBuilder.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/deployment/DeploymentModelBuilderJAXRPC_EJB21.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/deployment/DeploymentModelBuilderJAXRPC_JSE.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/deployment/DeploymentModelBuilderJAXWS_EJB3.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/deployment/DeploymentModelBuilderJAXWS_JSE.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/deployment/WSDeploymentBuilder.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/deployment/WSVirtualFileFilter.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/endpoint/HornetQJMSResolver.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/injection/EJBBeanReferenceResolver.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/injection/InjectionMetaDataDeploymentAspect.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/invocation/InvocationHandlerEJB21.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/invocation/InvocationHandlerEJB3.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/invocation/InvocationHandlerFactoryImpl.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/invocation/InvocationHandlerMDB21.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/invocation/InvocationHandlerMDB3.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/invocation/ServiceEndpointInterceptorEJB21.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/ioc/IoCContainerProxyFactoryImpl.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/ioc/IoCContainerProxyImpl.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/metadata/AbstractMetaDataBuilderEJB.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/metadata/ContainerMetaDataDeploymentAspect.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/metadata/MetaDataBuilderEJB21.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/metadata/MetaDataBuilderEJB3.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/metadata/MetaDataBuilderJSE.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/metadata/PublishLocationAdapterImpl.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/security/JACCPermissionsDeploymentAspect.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/security/SecurityAdapterFactoryImpl.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/security/SecurityAdapterImpl.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/tomcat/AbstractSecurityMetaDataAccessorEJB.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/tomcat/SecurityMetaDataAccessorEJB.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/tomcat/SecurityMetaDataAccessorEJB21.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/tomcat/SecurityMetaDataAccessorEJB3.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/tomcat/WebMetaDataCreatingDeploymentAspect.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/tomcat/WebMetaDataCreator.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/tomcat/WebMetaDataModifier.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/tomcat/WebMetaDataModifyingDeploymentAspect.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/util/ASHelper.java
   trunk/webservices/src/main/java/org/jboss/webservices/integration/util/WebMetaDataHelper.java
   trunk/webservices/src/resources/jbossws-jboss.deployer/META-INF/stack-agnostic-jboss-beans.xml
Log:
[JBWS-3086] reviewed and merged JMS prototype upstream

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/config/ServerConfigFactoryImpl.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/config/ServerConfigFactoryImpl.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/config/ServerConfigFactoryImpl.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -36,7 +36,6 @@
  */
 public final class ServerConfigFactoryImpl extends ServerConfigFactory
 {
-   
    /** The bean name in the kernel registry. */
    private static final String BEAN_NAME = "WSServerConfig";
 
@@ -50,7 +49,7 @@
 
    /**
     * Returns config registered in MC kernel.
-    * 
+    *
     * @return config
     */
    public ServerConfig getServerConfig()
@@ -58,8 +57,7 @@
       final SPIProvider spiProvider = SPIProviderResolver.getInstance().getProvider();
       final IoCContainerProxyFactory iocContainerFactory = spiProvider.getSPI(IoCContainerProxyFactory.class);
       final IoCContainerProxy iocContainer = iocContainerFactory.getContainer();
-      
+
       return iocContainer.getBean(ServerConfigFactoryImpl.BEAN_NAME, ServerConfig.class);
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/config/ServerConfigImpl.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/config/ServerConfigImpl.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/config/ServerConfigImpl.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -40,7 +40,6 @@
  */
 public final class ServerConfigImpl extends AbstractServerConfig implements AbstractServerConfigMBean
 {
-
    /**
     * Constructor.
     */
@@ -51,17 +50,17 @@
 
    /**
     * Gets server temp directory.
-    * 
+    *
     * @return temp directory
     */
    public File getServerTempDir()
    {
       return this.getDirFromServerConfig("ServerTempLocation");
    }
-   
+
    /**
     * Gets server home directory.
-    * 
+    *
     * @return home directory
     */
    public File getHomeDir()
@@ -71,14 +70,14 @@
 
    /**
     * Gets server data directory.
-    * 
+    *
     * @return data directory
     */
    public File getServerDataDir()
    {
       return this.getDirFromServerConfig("ServerDataLocation");
    }
-   
+
    /**
     * Obtains the requested directory from the server configuration.
     *
@@ -114,5 +113,4 @@
 
       return dir;
    }
-
 }

Added: trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/AbstractDescriptorDeployer.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/AbstractDescriptorDeployer.java	                        (rev 0)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/AbstractDescriptorDeployer.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -0,0 +1,79 @@
+/*
+ * JBoss, Home of Professional Open Source.
+ * Copyright 2010, Red Hat Middleware LLC, and individual contributors
+ * as indicated by the @author tags. See the copyright.txt file in the
+ * distribution for a full listing of individual contributors.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+package org.jboss.webservices.integration.deployers;
+
+import org.jboss.deployers.vfs.spi.deployer.ObjectModelFactoryDeployer;
+import org.jboss.deployers.vfs.spi.structure.VFSDeploymentUnit;
+import org.jboss.vfs.VFSInputSource;
+import org.jboss.vfs.VirtualFile;
+import org.jboss.wsf.spi.metadata.DescriptorProcessor;
+import org.jboss.xb.binding.ObjectModelFactory;
+import org.xml.sax.InputSource;
+
+/**
+ * Abstract descriptor deployer which deploys only if particular DD processor is available.
+ *
+ * @author <a href="mailto:ropalka at redhat.com">Richard Opalka</a>
+ */
+abstract class AbstractDescriptorDeployer<P extends DescriptorProcessor<T>, T> extends ObjectModelFactoryDeployer<T>
+{
+   private P ddProcessor;
+
+   AbstractDescriptorDeployer(Class<T> output)
+   {
+      super(output);
+      this.setName("UNSPECIFIED");
+      this.setUseSchemaValidation(false);
+   }
+
+   @Override
+   protected T parse(final VFSDeploymentUnit unit, final VirtualFile file, final T root) throws Exception
+   {
+      if (this.ddProcessor != null)
+      {
+         InputSource source = new VFSInputSource(file);
+         ObjectModelFactory factory = this.ddProcessor.getFactory(file.toURL());
+         return getHelper().parse(source, root, factory);
+      }
+
+      return null;
+   }
+
+   /**
+    * MC incallback method. It will be invoked each time subclass specific DescriptorProcessor bean will be installed.
+    */
+   protected void setProcessor(final P ddProcessor)
+   {
+      if (this.ddProcessor != null)
+         throw new IllegalStateException("Only one " + this.ddProcessor.getClass() + " instance can be installed in MC");
+
+      this.ddProcessor = ddProcessor;
+      this.setName(this.ddProcessor.getDescriptorName());
+      this.setUseSchemaValidation(this.ddProcessor.isValidating());
+   }
+
+   @Override
+   protected ObjectModelFactory getObjectModelFactory(final T root)
+   {
+      throw new UnsupportedOperationException();
+   }
+}

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/JAXRPCAppClientClassPathDeployer.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/JAXRPCAppClientClassPathDeployer.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/JAXRPCAppClientClassPathDeployer.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -31,10 +31,9 @@
  * when a application-client.xml descriptor file is found in the deployment.
  * This deployer then actually enables classpath modification when a jaxrpc-mapping
  * is specified in the descriptor.
- * 
+ *
  * @author alessio.soldano at jboss.com
  * @since 03-Feb-2010
- *
  */
 public class JAXRPCAppClientClassPathDeployer extends JAXRPCClientClassPathDeployer<ApplicationClientMetaData>
 {
@@ -42,7 +41,7 @@
    {
       super(ApplicationClientMetaData.class);
    }
-   
+
    @Override
    protected boolean isClassPathChangeRequired(VFSDeploymentUnit unit)
    {

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/JAXRPCClientClassPathDeployer.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/JAXRPCClientClassPathDeployer.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/JAXRPCClientClassPathDeployer.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -32,10 +32,9 @@
  * when a application-client.xml descriptor file is found in the deployment.
  * This deployer then actually enables classpath modification when a jaxrpc-mapping
  * is specified in the descriptor.
- * 
+ *
  * @author alessio.soldano at jboss.com
  * @since 03-Feb-2010
- *
  */
 public abstract class JAXRPCClientClassPathDeployer<T> extends JAXRPCIntegrationClassPathDeployer<T>
 {
@@ -44,7 +43,7 @@
       super(input);
       setInput(input); //makes the input mandatory instead of optional
    }
-   
+
    protected static boolean hasJaxRpcMappingReference(ServiceReferencesMetaData serviceReferences)
    {
       if (serviceReferences != null)
@@ -60,5 +59,4 @@
       }
       return false;
    }
-   
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/JAXRPCEjbClientClassPathDeployer.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/JAXRPCEjbClientClassPathDeployer.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/JAXRPCEjbClientClassPathDeployer.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -35,10 +35,9 @@
  * when a ejb-jar.xml descriptor file is found in the deployment.
  * This deployer then actually enables classpath modification when a jaxrpc-mapping
  * is specified in the descriptor.
- * 
+ *
  * @author alessio.soldano at jboss.com
  * @since 03-Feb-2010
- *
  */
 public class JAXRPCEjbClientClassPathDeployer extends JAXRPCClientClassPathDeployer<EjbJarMetaData>
 {
@@ -46,7 +45,7 @@
    {
       super(EjbJarMetaData.class);
    }
-   
+
    @Override
    protected boolean isClassPathChangeRequired(VFSDeploymentUnit unit)
    {

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/JAXRPCIntegrationClassPathDeployer.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/JAXRPCIntegrationClassPathDeployer.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/JAXRPCIntegrationClassPathDeployer.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -36,25 +36,22 @@
  * An abstract deployer that properly set the classpath for JAX-RPC deployments.
  * This is performed adding a reference to an integration lib from the jaxrpc
  * deployers to the deployment unit's classpath.
- * 
+ *
  * @author alessio.soldano at jboss.com
  * @since 02-Feb-2010
- *
  */
 public abstract class JAXRPCIntegrationClassPathDeployer<T> extends UrlIntegrationDeployer<T>
 {
    private Set<String> libs;
-   
    private boolean integrationLibsFound = false;
    private ServerConfig wsServerConfig;
    private boolean stackRequiresIntegration;
-   
-   
+
    public JAXRPCIntegrationClassPathDeployer(Class<T> input)
    {
       super(input);
    }
-   
+
    protected abstract boolean isClassPathChangeRequired(VFSDeploymentUnit unit);
 
    @Override
@@ -62,13 +59,13 @@
    {
       return stackRequiresIntegration && integrationLibsFound && isClassPathChangeRequired(unit);
    }
-   
+
    @Override
    public void start()
    {
       //NOOP
    }
-   
+
    protected Set<URL> getJBossWSIntegrationUrls()
    {
       Set<URL> result = new HashSet<URL>();
@@ -97,12 +94,7 @@
       }
       return result;
    }
-   
-   /**
-    * Get server home.
-    *
-    * @return the jboss server home location
-    */
+
    protected String getServerHome()
    {
       return "${jboss.server.home.url}";
@@ -130,5 +122,4 @@
       //the Native stack does not requires the JAXRPC additional integration 
       stackRequiresIntegration = !wsServerConfig.getImplementationTitle().toLowerCase().contains("native");
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/JAXRPCServerClassPathDeployer.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/JAXRPCServerClassPathDeployer.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/JAXRPCServerClassPathDeployer.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -30,10 +30,9 @@
  * A deployer for properly setting the classpath for jaxrpc endpoint deployments;
  * it's triggered by the WebservicesMetaData which is attached to the unit
  * when a webservice.xml descriptor file is found in the deployment.
- * 
+ *
  * @author alessio.soldano at jboss.com
  * @since 03-Feb-2010
- *
  */
 public class JAXRPCServerClassPathDeployer extends JAXRPCIntegrationClassPathDeployer<WebservicesMetaData>
 {
@@ -42,7 +41,7 @@
       super(WebservicesMetaData.class);
       setInput(WebservicesMetaData.class); //makes the input mandatory instead of optional
    }
-   
+
    @Override
    protected boolean isClassPathChangeRequired(VFSDeploymentUnit unit)
    {

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/JAXRPCServletClientClassPathDeployer.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/JAXRPCServletClientClassPathDeployer.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/JAXRPCServletClientClassPathDeployer.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -31,10 +31,9 @@
  * when a web.xml descriptor file is found in the deployment.
  * This deployer then actually enables classpath modification when a jaxrpc-mapping
  * is specified in the descriptor.
- * 
+ *
  * @author alessio.soldano at jboss.com
  * @since 03-Feb-2010
- *
  */
 public class JAXRPCServletClientClassPathDeployer extends JAXRPCClientClassPathDeployer<WebMetaData>
 {
@@ -42,7 +41,7 @@
    {
       super(WebMetaData.class);
    }
-   
+
    @Override
    protected boolean isClassPathChangeRequired(VFSDeploymentUnit unit)
    {

Added: trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/JMSDescriptorDeployer.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/JMSDescriptorDeployer.java	                        (rev 0)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/JMSDescriptorDeployer.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -0,0 +1,51 @@
+/*
+ * JBoss, Home of Professional Open Source.
+ * Copyright 2010, Red Hat Middleware LLC, and individual contributors
+ * as indicated by the @author tags. See the copyright.txt file in the
+ * distribution for a full listing of individual contributors.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+package org.jboss.webservices.integration.deployers;
+
+import org.jboss.wsf.spi.metadata.jms.JMSDescriptorProcessor;
+import org.jboss.wsf.spi.metadata.jms.JMSEndpointsMetaData;
+
+/**
+ * Stack agnostic JMS descriptor deployer.
+ *
+ * @author <a href="mailto:ropalka at redhat.com">Richard Opalka</a>
+ */
+public final class JMSDescriptorDeployer extends AbstractDescriptorDeployer<JMSDescriptorProcessor, JMSEndpointsMetaData>
+{
+   /**
+    * Constructor.
+    */
+   public JMSDescriptorDeployer()
+   {
+      super(JMSEndpointsMetaData.class);
+   }
+
+   /**
+    * MC incallback method. It will be invoked each time JMSDescriptorProcessor bean will be installed.
+    * @param processor the processor
+    */
+   @Override
+   public void setProcessor(final JMSDescriptorProcessor processor)
+   {
+      super.setProcessor(processor);
+   }
+}

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/SecurityActions.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/SecurityActions.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/SecurityActions.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -25,16 +25,16 @@
 import java.security.PrivilegedAction;
 
 /**
- * 
+ * Security actions helper.
+ *
  * @author alessio.soldano at jboss.com
  * @since 17-Feb-2010
- *
  */
 class SecurityActions
 {
    /**
     * Get context classloader.
-    * 
+    *
     * @return the current context classloader
     */
    static ClassLoader getContextClassLoader()
@@ -54,7 +54,7 @@
          });
       }
    }
-   
+
    /**
     * Set context classloader.
     *
@@ -78,5 +78,4 @@
          });
       }
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/WSAspectizedDeployersFactory.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/WSAspectizedDeployersFactory.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/WSAspectizedDeployersFactory.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -36,7 +36,6 @@
  */
 public final class WSAspectizedDeployersFactory
 {
-
    /** Logger. */
    private static final Logger LOGGER = Logger.getLogger(WSAspectizedDeployersFactory.class);
 
@@ -45,10 +44,10 @@
 
    /** Our deployers regitry. */
    private final Map<DeploymentAspect, Deployer> deployersRegistry = new HashMap<DeploymentAspect, Deployer>();
-   
+
    /**
     * Constructor.
-    * 
+    *
     * @param realDeployers real deployers registry
     */
    public WSAspectizedDeployersFactory(final DeployersImpl realDeployers)
@@ -58,7 +57,7 @@
 
    /**
     * MC incallback method. It will be called each time DeploymentAspect bean will be installed.
-    * 
+    *
     * @param aspect to create real WS aspectized deployer for
     */
    public void addDeployer(final DeploymentAspect aspect)
@@ -75,7 +74,7 @@
 
    /**
     * MC uncallback method. It will be called each time DeploymentAspect bean will be removed.
-    * 
+    *
     * @param aspect to remove real WS aspectized deployer for
     */
    public void removeDeployer(final DeploymentAspect aspect)
@@ -89,5 +88,4 @@
       this.deployersRegistry.remove(aspect);
       this.delegee.removeDeployer(wsAspectizedDeployer);
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/WSDeploymentAspectDeployer.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/WSDeploymentAspectDeployer.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/WSDeploymentAspectDeployer.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -23,17 +23,19 @@
 
 import java.util.Set;
 
+import org.jboss.beans.metadata.spi.BeanMetaData;
 import org.jboss.deployers.spi.DeploymentException;
 import org.jboss.deployers.spi.deployer.helpers.AbstractRealDeployer;
 import org.jboss.deployers.structure.spi.DeploymentUnit;
 import org.jboss.metadata.web.jboss.JBossWebMetaData;
 import org.jboss.webservices.integration.util.ASHelper;
+import org.jboss.wsf.common.integration.JMSDeploymentAspect;
 import org.jboss.wsf.spi.deployment.Deployment;
 import org.jboss.wsf.spi.deployment.DeploymentAspect;
 
 /**
  * A deployer that delegates to JBossWS deployment aspect.
- * 
+ *
  * @author <a href="mailto:ropalka at redhat.com">Richard Opalka</a>
  */
 final class WSDeploymentAspectDeployer extends AbstractRealDeployer
@@ -50,21 +52,35 @@
 
    /**
     * Constructor.
-    * 
+    *
     * @param aspect deployment aspect
     */
    WSDeploymentAspectDeployer(final DeploymentAspect aspect)
    {
       super();
-
-      // inputs
-      this.addInput(JBossWebMetaData.class);
-      this.addInput(Deployment.class);
-      if (aspect.isLast())
+      if (aspect instanceof JMSDeploymentAspect)
       {
-         this.addInput(WSDeploymentAspectDeployer.JBOSSWS_METADATA);
+         // inputs
+         this.addInput(org.jboss.system.metadata.ServiceDeployment.class);
+         this.addInput(org.jboss.system.metadata.ServiceMetaData.class);
       }
+      else
+      {
+         // inputs
+         this.addInput(JBossWebMetaData.class);
+         this.addInput(Deployment.class);
+         if (aspect.isLast())
+         {
+            this.addInput(WSDeploymentAspectDeployer.JBOSSWS_METADATA);
+         }
 
+         // outputs
+         this.addOutput(JBossWebMetaData.class);
+         if (!aspect.isLast())
+         {
+            this.addOutput(WSDeploymentAspectDeployer.JBOSSWS_METADATA);
+         }
+      }
       // propagate DA requirements and map them to deployer inputs
       final Set<String> inputs = aspect.getRequiresAsSet();
       for (String input : inputs)
@@ -72,13 +88,6 @@
          this.addInput(WSDeploymentAspectDeployer.JBOSSWS_ATTACHMENT_PREFIX + input);
       }
 
-      // outputs
-      this.addOutput(JBossWebMetaData.class);
-      if (!aspect.isLast())
-      {
-         this.addOutput(WSDeploymentAspectDeployer.JBOSSWS_METADATA);
-      }
-
       // propagate DA provides and map them to deployer outputs
       final Set<String> outputs = aspect.getProvidesAsSet();
       for (String output : outputs)
@@ -93,7 +102,7 @@
    /**
     * If deployed unit is related to web services this method delegates
     * to deployment aspect and calls its create() and start() methods.
-    * 
+    *
     * @param unit deployment unit
     * @throws DeploymentException on deployment failure
     */
@@ -124,7 +133,7 @@
    /**
     * If undeployed unit is related to web services this method delegates
     * to deployment aspect and calls its stop() and destroy() methods.
-    * 
+    *
     * @param unit deployment unit
     */
    @Override
@@ -153,7 +162,7 @@
 
    /**
     * Displays also WS deployment aspect being wrapped.
-    * 
+    *
     * @return deployer instance id including wrapped deployment aspect id.
     */
    @Override
@@ -163,5 +172,4 @@
       sb.append(super.toString()).append('(').append(this.aspect).append(')');
       return sb.toString();
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/WSDeploymentDeployer.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/WSDeploymentDeployer.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/WSDeploymentDeployer.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -30,13 +30,12 @@
 import org.jboss.wsf.spi.deployment.Deployment.DeploymentType;
 
 /**
- * This deployer initializes JBossWS deployment meta data. 
+ * This deployer initializes JBossWS deployment meta data.
  *
  * @author <a href="mailto:ropalka at redhat.com">Richard Opalka</a>
  */
 public final class WSDeploymentDeployer extends AbstractRealDeployer
 {
-
    /**
     * Constructor.
     */
@@ -55,7 +54,7 @@
 
    /**
     * Creates new Web Service deployment and registers it with deployment unit.
-    * 
+    *
     * @param unit deployment unit
     * @throws DeploymentException if any error occurs
     */
@@ -65,5 +64,4 @@
       this.log.trace("Building JBoss agnostic webservices meta data model");
       WSDeploymentBuilder.getInstance().build(unit);
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/WSDescriptorDeployer.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/WSDescriptorDeployer.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/WSDescriptorDeployer.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -21,19 +21,16 @@
  */
 package org.jboss.webservices.integration.deployers;
 
-import org.jboss.deployers.vfs.spi.deployer.ObjectModelFactoryDeployer;
-import org.jboss.wsf.spi.metadata.webservices.WebservicesFactory;
+import org.jboss.wsf.spi.metadata.webservices.WebservicesDescriptorProcessor;
 import org.jboss.wsf.spi.metadata.webservices.WebservicesMetaData;
-import org.jboss.xb.binding.ObjectModelFactory;
 
 /**
  * webservices.xml deployer.
  *
  * @author <a href="mailto:ropalka at redhat.com">Richard Opalka</a>
  */
-public final class WSDescriptorDeployer extends ObjectModelFactoryDeployer<WebservicesMetaData>
+public final class WSDescriptorDeployer extends AbstractDescriptorDeployer<WebservicesDescriptorProcessor, WebservicesMetaData>
 {
-
    /**
     * Constructor.
     */
@@ -43,16 +40,12 @@
    }
 
    /**
-    * Model factory generator.
-    * 
-    * @param root object tree root
-    * @return object model factory
+    * MC incallback method. It will be invoked each time WebservicesDescriptorProcessor bean will be installed.
+    * @param processor the processor
     */
    @Override
-   protected ObjectModelFactory getObjectModelFactory(final WebservicesMetaData root)
+   public void setProcessor(final WebservicesDescriptorProcessor processor)
    {
-      this.log.debug("Returning webservices descriptor factory");
-      return new WebservicesFactory(null);
+      super.setProcessor(processor);
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/WSEJBAdapterDeployer.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/WSEJBAdapterDeployer.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/WSEJBAdapterDeployer.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -49,7 +49,6 @@
  */
 public final class WSEJBAdapterDeployer extends AbstractRealDeployer
 {
-
    /**
     * Constructor.
     */
@@ -69,7 +68,7 @@
 
    /**
     * Deploys WebServiceDeployment meta data.
-    * 
+    *
     * @param unit deployment unit
     * @throws DeploymentException exception
     */
@@ -107,7 +106,7 @@
 
    /**
     * Returns EJB container if EJB3 deployment is detected and EJB meta data does not represent entity bean.
-    * 
+    *
     * @param ejb3Deployment EJB3 deployment meta data
     * @param ejbMD EJB meta data
     * @return EJB container or null if not EJB3 stateless bean
@@ -150,7 +149,7 @@
 
       /**
        * Constructor.
-       * 
+       *
        * @param ejbMetaData EJB metadata
        * @param ejbContainer EJB container
        * @param loader class loader
@@ -234,7 +233,6 @@
                   + " from loader: " + this.loader);
          }
       }
-
    }
 
    /**
@@ -243,7 +241,6 @@
     */
    private static final class WebServiceDeploymentAdapter implements WebServiceDeployment
    {
-
       /** List of endpoints. */
       private final List<WebServiceDeclaration> endpoints = new ArrayList<WebServiceDeclaration>();
 
@@ -257,14 +254,12 @@
 
       /**
        * Returns endpoints list.
-       * 
+       *
        * @return endpoints list
        */
       public List<WebServiceDeclaration> getServiceEndpoints()
       {
          return this.endpoints;
       }
-
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/WSTypeDeployer.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/WSTypeDeployer.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/WSTypeDeployer.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -29,6 +29,7 @@
 import org.jboss.webservices.integration.util.ASHelper;
 import org.jboss.wsf.spi.deployment.Deployment.DeploymentType;
 import org.jboss.wsf.spi.deployment.integration.WebServiceDeployment;
+import org.jboss.wsf.spi.metadata.jms.JMSEndpointsMetaData;
 import org.jboss.wsf.spi.metadata.webservices.WebservicesMetaData;
 
 /**
@@ -38,7 +39,6 @@
  */
 public final class WSTypeDeployer extends AbstractRealDeployer
 {
-
    /**
     * Constructor.
     */
@@ -58,7 +58,7 @@
 
    /**
     * Detects WS deployment type and puts it to the deployment unit attachments.
-    * 
+    *
     * @param unit deployment unit
     * @throws DeploymentException on failure
     */
@@ -85,11 +85,16 @@
          this.log.debug("Detected JAXRPC EJB21 deployment");
          unit.addAttachment(DeploymentType.class, DeploymentType.JAXRPC_EJB21);
       }
+      else if (this.isJaxwsJmsDeployment(unit))
+      {
+         this.log.debug("Detected JAXWS JMS deployment");
+         unit.addAttachment(DeploymentType.class, DeploymentType.JAXWS_JMS);
+      }
    }
 
    /**
     * Returns true if JAXRPC EJB deployment is detected.
-    * 
+    *
     * @param unit deployment unit
     * @return true if JAXRPC EJB, false otherwise
     */
@@ -103,7 +108,7 @@
 
    /**
     * Returns true if JAXRPC JSE deployment is detected.
-    * 
+    *
     * @param unit deployment unit
     * @return true if JAXRPC JSE, false otherwise
     */
@@ -122,7 +127,7 @@
 
    /**
     * Returns true if JAXWS EJB deployment is detected.
-    * 
+    *
     * @param unit deployment unit
     * @return true if JAXWS EJB, false otherwise
     */
@@ -140,7 +145,7 @@
 
    /**
     * Returns true if JAXWS JSE deployment is detected.
-    * 
+    *
     * @param unit deployment unit
     * @return true if JAXWS JSE, false otherwise
     */
@@ -156,4 +161,14 @@
       return false;
    }
 
+   /**
+    * Returns true if JAXWS JMS deployment is detected.
+    *
+    * @param unit deployment unit
+    * @return true if JAXWS JMS, false otherwise
+    */
+   private boolean isJaxwsJmsDeployment(final DeploymentUnit unit)
+   {
+      return ASHelper.hasAttachment(unit, JMSEndpointsMetaData.class);
+   }
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/deployment/AbstractDeploymentModelBuilder.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/deployment/DeploymentModelBuilder.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/deployment/DeploymentModelBuilder.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -4,17 +4,15 @@
 
 /**
  * Deployment builder interface.
- * 
+ *
  * @author <a href="mailto:ropalka at redhat.com">Richard Opalka</a>
  */
 interface DeploymentModelBuilder
 {
-
    /**
     * Creates Web Service deployment model and associates it with deployment.
-    * 
+    *
     * @param unit deployment unit
     */
    void newDeploymentModel(DeploymentUnit unit);
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/deployment/DeploymentModelBuilderJAXRPC_EJB21.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/deployment/DeploymentModelBuilderJAXRPC_EJB21.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/deployment/DeploymentModelBuilderJAXRPC_EJB21.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -11,12 +11,11 @@
 
 /**
  * Creates new JAXRPC EJB21 deployment.
- * 
+ *
  * @author <a href="mailto:ropalka at redhat.com">Richard Opalka</a>
  */
 final class DeploymentModelBuilderJAXRPC_EJB21 extends AbstractDeploymentModelBuilder
 {
-
    /**
     * Constructor.
     */
@@ -27,7 +26,7 @@
 
    /**
     * Creates new JAXRPC EJB21 deployment and registers it with deployment unit.
-    * 
+    *
     * @param dep webservice deployment
     * @param unit deployment unit
     */
@@ -49,9 +48,8 @@
             final String ejbClass = beanMetaData.getEjbClass();
             this.log.debug("EJB21 class: " + ejbClass);
 
-            this.newEndpoint(ejbClass, ejbName, dep);
+            this.newHttpEndpoint(ejbClass, ejbName, dep);
          }
       }
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/deployment/DeploymentModelBuilderJAXRPC_JSE.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/deployment/DeploymentModelBuilderJAXRPC_JSE.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/deployment/DeploymentModelBuilderJAXRPC_JSE.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -11,12 +11,11 @@
 
 /**
  * Creates new JAXRPC JSE deployment.
- * 
+ *
  * @author <a href="mailto:ropalka at redhat.com">Richard Opalka</a>
  */
 final class DeploymentModelBuilderJAXRPC_JSE extends AbstractDeploymentModelBuilder
 {
-
    /**
     * Constructor.
     */
@@ -27,7 +26,7 @@
 
    /**
     * Creates new JAXRPC JSE deployment and registers it with deployment unit.
-    * 
+    *
     * @param dep webservice deployment
     * @param unit deployment unit
     */
@@ -48,9 +47,8 @@
             final String servletClass = ASHelper.getEndpointName(servletMD);
             this.log.debug("JSE class: " + servletClass);
 
-            this.newEndpoint(servletClass, servletName, dep);
+            this.newHttpEndpoint(servletClass, servletName, dep);
          }
       }
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/deployment/DeploymentModelBuilderJAXWS_EJB3.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/deployment/DeploymentModelBuilderJAXWS_EJB3.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/deployment/DeploymentModelBuilderJAXWS_EJB3.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -10,12 +10,11 @@
 
 /**
  * Creates new JAXWS EJB3 deployment.
- * 
+ *
  * @author <a href="mailto:ropalka at redhat.com">Richard Opalka</a>
  */
 final class DeploymentModelBuilderJAXWS_EJB3 extends AbstractDeploymentModelBuilder
 {
-
    /**
     * Constructor.
     */
@@ -26,7 +25,7 @@
 
    /**
     * Creates new JAXWS EJB3 deployment and registers it with deployment unit.
-    * 
+    *
     * @param dep webservice deployment
     * @param unit deployment unit
     */
@@ -44,9 +43,8 @@
          final String ejbClass = container.getComponentClassName();
          this.log.debug("EJB3 class: " + ejbClass);
 
-         final Endpoint ep = this.newEndpoint(ejbClass, ejbName, dep);
+         final Endpoint ep = this.newHttpEndpoint(ejbClass, ejbName, dep);
          ep.setProperty(ASHelper.CONTAINER_NAME, container.getContainerName());
       }
    }
-
 }

Added: trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/deployment/DeploymentModelBuilderJAXWS_JMS.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/deployment/DeploymentModelBuilderJAXWS_JMS.java	                        (rev 0)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/deployment/DeploymentModelBuilderJAXWS_JMS.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -0,0 +1,69 @@
+/*
+ * JBoss, Home of Professional Open Source.
+ * Copyright 2010, Red Hat Middleware LLC, and individual contributors
+ * as indicated by the @author tags. See the copyright.txt file in the
+ * distribution for a full listing of individual contributors.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+package org.jboss.webservices.integration.deployers.deployment;
+
+import java.util.List;
+
+import org.jboss.deployers.structure.spi.DeploymentUnit;
+import org.jboss.metadata.web.jboss.JBossWebMetaData;
+import org.jboss.metadata.web.spec.ServletMetaData;
+import org.jboss.webservices.integration.util.ASHelper;
+import org.jboss.wsf.spi.deployment.Deployment;
+import org.jboss.wsf.spi.metadata.jms.JMSEndpointMetaData;
+import org.jboss.wsf.spi.metadata.jms.JMSEndpointsMetaData;
+
+/**
+ * Create JAXWS SPI Deployment for JAXWS_JMS type deployment.
+ *
+ * @author <a herf="ema at redhat.com>Jim Ma</a>
+ */
+public class DeploymentModelBuilderJAXWS_JMS extends AbstractDeploymentModelBuilder
+{
+   /**
+    * Constructor.
+    */
+   DeploymentModelBuilderJAXWS_JMS()
+   {
+      super();
+   }
+
+   /**
+    * Creates new JAXWS JMS deployment and registers it with deployment unit.
+    *
+    * @param dep webservice deployment
+    * @param unit deployment unit
+    */
+   @Override
+   protected void build(final Deployment dep, final DeploymentUnit unit)
+   {
+      this.getAndPropagateAttachment(JMSEndpointsMetaData.class, unit, dep);
+      JMSEndpointsMetaData jmsEndpointsMD = dep.getAttachment(JMSEndpointsMetaData.class);
+      for (JMSEndpointMetaData endpoint : jmsEndpointsMD.getEndpointsMetaData())
+      {
+         if (endpoint.getName() == null) 
+         {
+            endpoint.setName(endpoint.getImplementor());
+         }
+         this.newJMSEndpoint(endpoint.getImplementor(), endpoint.getName(), dep);
+      }
+   }
+}
\ No newline at end of file

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/deployment/DeploymentModelBuilderJAXWS_JSE.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/deployment/DeploymentModelBuilderJAXWS_JSE.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/deployment/DeploymentModelBuilderJAXWS_JSE.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -10,12 +10,11 @@
 
 /**
  * Creates new JAXWS JSE deployment.
- * 
+ *
  * @author <a href="mailto:ropalka at redhat.com">Richard Opalka</a>
  */
 final class DeploymentModelBuilderJAXWS_JSE extends AbstractDeploymentModelBuilder
 {
-
    /**
     * Constructor.
     */
@@ -26,7 +25,7 @@
 
    /**
     * Creates new JAXWS JSE deployment and registers it with deployment unit.
-    * 
+    *
     * @param dep webservice deployment
     * @param unit deployment unit
     */
@@ -44,8 +43,7 @@
          final String servletClass = ASHelper.getEndpointName(servlet);
          this.log.debug("JSE class: " + servletClass);
 
-         this.newEndpoint(servletClass, servletName, dep);
+         this.newHttpEndpoint(servletClass, servletName, dep);
       }
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/deployment/WSDeploymentBuilder.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/deployment/WSDeploymentBuilder.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/deployment/WSDeploymentBuilder.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -35,7 +35,6 @@
  */
 public final class WSDeploymentBuilder
 {
-
    /** Builder instance. */
    private static final WSDeploymentBuilder SINGLETON = new WSDeploymentBuilder();
 
@@ -48,6 +47,7 @@
       WSDeploymentBuilder.builders.put(DeploymentType.JAXRPC_JSE, new DeploymentModelBuilderJAXRPC_JSE());
       WSDeploymentBuilder.builders.put(DeploymentType.JAXWS_EJB3, new DeploymentModelBuilderJAXWS_EJB3());
       WSDeploymentBuilder.builders.put(DeploymentType.JAXRPC_EJB21, new DeploymentModelBuilderJAXRPC_EJB21());
+      WSDeploymentBuilder.builders.put(DeploymentType.JAXWS_JMS, new DeploymentModelBuilderJAXWS_JMS());
    }
 
    /**
@@ -60,7 +60,7 @@
 
    /**
     * Factory method for obtaining builder instance. 
-    * 
+    *
     * @return builder instance
     */
    public static WSDeploymentBuilder getInstance()
@@ -70,7 +70,7 @@
 
    /**
     * Builds JBossWS deployment model if web service deployment is detected.
-    * 
+    *
     * @param unit deployment unit
     */
    public void build(final DeploymentUnit unit)
@@ -82,5 +82,4 @@
          WSDeploymentBuilder.builders.get(deploymentType).newDeploymentModel(unit);
       }
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/deployment/WSVirtualFileFilter.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/deployment/WSVirtualFileFilter.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/deployment/WSVirtualFileFilter.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -1,3 +1,24 @@
+/*
+ * JBoss, Home of Professional Open Source.
+ * Copyright 2009, Red Hat Middleware LLC, and individual contributors
+ * as indicated by the @author tags. See the copyright.txt file in the
+ * distribution for a full listing of individual contributors.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
 package org.jboss.webservices.integration.deployers.deployment;
 
 import org.jboss.vfs.VirtualFile;
@@ -6,18 +27,17 @@
 
 /**
  * WS file filter for files with the '.wsdl', or '.xsd' or '.xml' suffix. 
- * 
+ *
  * @author <a href="mailto:dbevenius at jboss.com">Daniel Bevenius</a>
  * @author <a href="mailto:ropalka at redhat.com">Richard Opalka</a>
  */
 final class WSVirtualFileFilter implements VirtualFileFilterWithAttributes
 {
-
    /** The tree walking attributes. */
    private VisitorAttributes attributes;
 
    /**
-    * Constructor. 
+    * Constructor.
     */
    WSVirtualFileFilter()
    {
@@ -26,7 +46,7 @@
 
    /**
     * Constructor.
-    * 
+    *
     * @param attributes visit attributes
     */
    WSVirtualFileFilter(final VisitorAttributes attributes)
@@ -36,7 +56,7 @@
 
    /**
     * Gets VisitorAttributes for this instance.
-    * 
+    *
     * @return visitor attributes
     */
    public VisitorAttributes getAttributes()
@@ -64,5 +84,4 @@
 
       return hasWsdlSuffix || hasXsdSuffix || hasXmlSuffix;
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/endpoint/HornetQJMSResolver.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/endpoint/HornetQJMSResolver.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/endpoint/HornetQJMSResolver.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -29,9 +29,8 @@
 
 /**
  * A JMS endpoint resolver meant for working with HornetQ destination implementation
- * 
- * @author alessio.soldano at jboss.com
  *
+ * @author alessio.soldano at jboss.com
  */
 public class HornetQJMSResolver extends DefaultJMSEndpointResolver
 {
@@ -46,5 +45,4 @@
          super.setDestination(destination);
       }
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/injection/EJBBeanReferenceResolver.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/injection/EJBBeanReferenceResolver.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/injection/EJBBeanReferenceResolver.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -38,7 +38,6 @@
  */
 final class EJBBeanReferenceResolver extends AbstractReferenceResolver<EJB>
 {
-
    /**
     * Deployment unit used for resolving process.
     */
@@ -74,7 +73,7 @@
 
    /**
     * @see org.jboss.wsf.common.injection.resolvers.AbstractReferenceResolver#resolveField(java.lang.reflect.Field)
-    * 
+    *
     * @param field to be resolved
     * @return JNDI name of referenced EJB object
     */
@@ -90,7 +89,7 @@
 
    /**
     * @see org.jboss.wsf.common.injection.resolvers.AbstractReferenceResolver#resolveMethod(java.lang.reflect.Method)
-    * 
+    *
     * @param method to be resolved
     * @return JNDI name of referenced EJB object
     */
@@ -120,5 +119,4 @@
       }
       return new EjbReference(ejbAnnotation.beanName(), beanInterface, ejbAnnotation.mappedName());
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/injection/InjectionMetaDataDeploymentAspect.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/injection/InjectionMetaDataDeploymentAspect.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/injection/InjectionMetaDataDeploymentAspect.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -102,7 +102,7 @@
 
    /**
     * Builds injection meta data for all endpoints in deployment.
-    * 
+    *
     * @param dep webservice deployment
     */
    @Override
@@ -154,7 +154,7 @@
 
    /**
     * Returns environment entries meta data associated with specified EJB 3 bean.
-    * 
+    *
     * @param ejbName EJB 3 bean to lookup environment entries for
     * @param unit deployment unit
     * @return environment entries meta data
@@ -185,7 +185,7 @@
 
    /**
     * Builds JBossWS specific injections meta data.
-    * 
+    *
     * @param envEntriesMD environment entries meta data
     * @param resolvers known annotation resolvers
     * @param jndiContext JNDI context to be propagated
@@ -253,5 +253,4 @@
 
       return retVal;
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/invocation/InvocationHandlerEJB21.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/invocation/InvocationHandlerEJB21.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/invocation/InvocationHandlerEJB21.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -59,7 +59,6 @@
  */
 final class InvocationHandlerEJB21 extends AbstractInvocationHandler
 {
-
    /** EJB21 JNDI name. */
    private String jndiName;
 
@@ -74,14 +73,12 @@
     */
    InvocationHandlerEJB21()
    {
-      super();
-
       this.server = MBeanServerLocator.locateJBoss();
    }
 
    /**
     * Initializes EJB 21 endpoint.
-    * 
+    *
     * @param endpoint web service endpoint
     */
    public void init(final Endpoint endpoint)
@@ -107,7 +104,7 @@
 
    /**
     * Gets EJB 21 container name lazily.
-    * 
+    *
     * @param endpoint webservice endpoint
     * @return EJB21 container name
     */
@@ -133,7 +130,7 @@
 
    /**
     * Invokes EJB 21 endpoint.
-    * 
+    *
     * @param endpoint EJB 21 endpoint
     * @param wsInvocation web service invocation
     * @throws Exception if any error occurs
@@ -164,7 +161,7 @@
 
    /**
     * Returns configured EJB 21 JBoss MBean invocation.
-    * 
+    *
     * @param wsInvocation webservice invocation
     * @return configured JBoss invocation
     */
@@ -208,7 +205,7 @@
    /**
     * This method dynamically inserts EJB 21 webservice endpoint interceptor
     * to the last but one position in EJB 21 processing chain. See [JBWS-756] for more info.
-    * 
+    *
     * @param objectName EJB 21 object name
     * @param ejbName EJB 21 short name
     */
@@ -244,5 +241,4 @@
          this.log.warn("Cannot register EJB 21 service endpoint interceptor: ", ex);
       }
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/invocation/InvocationHandlerEJB3.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/invocation/InvocationHandlerEJB3.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/invocation/InvocationHandlerEJB3.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -64,8 +64,6 @@
     */
    InvocationHandlerEJB3()
    {
-      super();
-
       final SPIProvider spiProvider = SPIProviderResolver.getInstance().getProvider();
       final IoCContainerProxyFactory iocContainerFactory = spiProvider.getSPI(IoCContainerProxyFactory.class);
       this.iocContainer = iocContainerFactory.getContainer();
@@ -73,7 +71,7 @@
 
    /**
     * Initializes EJB3 container name.
-    * 
+    *
     * @param endpoint web service endpoint
     */
    public void init(final Endpoint endpoint)
@@ -88,7 +86,7 @@
 
    /**
     * Gets EJB 3 container lazily.
-    * 
+    *
     * @return EJB3 container
     */
    private synchronized ServiceEndpointContainer getEjb3Container()
@@ -109,7 +107,7 @@
 
    /**
     * Invokes EJB 3 endpoint.
-    * 
+    *
     * @param endpoint EJB 3 endpoint
     * @param wsInvocation web service invocation
     * @throws Exception if any error occurs
@@ -136,7 +134,7 @@
          this.handleInvocationException(t);
       }
    }
-   
+
    public Context getJNDIContext(final Endpoint ep) throws NamingException
    {
       final EJBContainer ejb3Container = (EJBContainer)getEjb3Container();
@@ -148,13 +146,12 @@
     */
    private static final class EJB3InvocationContextCallback implements InvocationContextCallback
    {
-
       /** WebService invocation. */
       private Invocation wsInvocation;
 
       /**
        * Constructor.
-       * 
+       *
        * @param wsInvocation delegee
        */
       public EJB3InvocationContextCallback(final Invocation wsInvocation)
@@ -164,7 +161,7 @@
 
       /**
        * Retrieves attachment type from Web Service invocation context attachments.
-       * 
+       *
        * @param <T> attachment type
        * @param attachmentType attachment class
        * @return attachment value
@@ -173,7 +170,5 @@
       {
          return this.wsInvocation.getInvocationContext().getAttachment(attachmentType);
       }
-
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/invocation/InvocationHandlerFactoryImpl.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/invocation/InvocationHandlerFactoryImpl.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/invocation/InvocationHandlerFactoryImpl.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -35,7 +35,6 @@
  */
 public final class InvocationHandlerFactoryImpl extends InvocationHandlerFactory
 {
-
    /**
     * Constructor.
     */
@@ -46,7 +45,7 @@
 
    /**
     * Returns invocation handler associated with invocation type.
-    * 
+    *
     * @param type invocation type
     * @return invocation handler
     */
@@ -80,5 +79,4 @@
 
       return handler;
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/invocation/InvocationHandlerMDB21.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/invocation/InvocationHandlerMDB21.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/invocation/InvocationHandlerMDB21.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -31,7 +31,6 @@
  */
 final class InvocationHandlerMDB21 extends AbstractInvocationHandlerJSE
 {
-
    /**
     * Constructor.
     */
@@ -39,5 +38,4 @@
    {
       super();
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/invocation/InvocationHandlerMDB3.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/invocation/InvocationHandlerMDB3.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/invocation/InvocationHandlerMDB3.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -31,7 +31,6 @@
  */
 final class InvocationHandlerMDB3 extends AbstractInvocationHandlerJSE
 {
-
    /**
     * Constructor.
     */
@@ -39,5 +38,4 @@
    {
       super();
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/invocation/ServiceEndpointInterceptorEJB21.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/invocation/ServiceEndpointInterceptorEJB21.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/invocation/ServiceEndpointInterceptorEJB21.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -31,16 +31,15 @@
 
 /**
  * This Interceptor does the ws4ee handler processing on EJB 21 endpoints.
- * 
+ *
  * According to the ws4ee spec the handler logic must be invoked after the container
- * applied method level security to the invocation. 
+ * applied method level security to the invocation.
  *
  * @author <a href="mailto:ropalka at redhat.com">Richard Opalka</a>
  * @author <a href="mailto:tdiesler at redhat.com">Thomas Diesler</a>
  */
 final class ServiceEndpointInterceptorEJB21 extends AbstractInterceptor
 {
-
    /**
     * Constructor.
     */
@@ -51,7 +50,7 @@
 
    /**
     * Before and after we call the EJB 21 service endpoint bean, we process the handler chains.
-    * 
+    *
     * @param jbossInvocation jboss invocation
     * @return ws invocation return value
     * @throws Exception if any error occurs
@@ -120,5 +119,4 @@
          throw ex;
       }
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/ioc/IoCContainerProxyFactoryImpl.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/ioc/IoCContainerProxyFactoryImpl.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/ioc/IoCContainerProxyFactoryImpl.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -31,7 +31,6 @@
  */
 public final class IoCContainerProxyFactoryImpl implements IoCContainerProxyFactory
 {
-   
    /** Container proxy singleton. */
    private static final IoCContainerProxy CONTAINER = IoCContainerProxyImpl.getInstance();
 
@@ -45,12 +44,11 @@
 
    /**
     * @see org.jboss.wsf.spi.ioc.IoCContainerProxyFactory#getContainer()
-    * 
+    *
     * @return IoC container proxy
     */
    public IoCContainerProxy getContainer()
    {
       return IoCContainerProxyFactoryImpl.CONTAINER;
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/ioc/IoCContainerProxyImpl.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/ioc/IoCContainerProxyImpl.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/ioc/IoCContainerProxyImpl.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -33,7 +33,6 @@
  */
 public final class IoCContainerProxyImpl implements IoCContainerProxy
 {
-
    /** Singleton. */
    private static final IoCContainerProxy SINGLETON = new IoCContainerProxyImpl();
    /** JBoss MC kernel. */
@@ -46,7 +45,7 @@
    {
       super();
    }
-   
+
    /**
     * Returns container proxy instance.
     *
@@ -56,10 +55,10 @@
    {
       return IoCContainerProxyImpl.SINGLETON;
    }
-   
+
    /**
     * Sets JBoss kernel - invoked via MC injection.
-    * 
+    *
     * @param kernel JBoss kernel
     */
    public void setKernel(final Kernel kernel)
@@ -84,5 +83,4 @@
 
       return (T)ctx.getTarget();
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/metadata/AbstractMetaDataBuilderEJB.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/metadata/AbstractMetaDataBuilderEJB.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/metadata/AbstractMetaDataBuilderEJB.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -44,13 +44,12 @@
  */
 abstract class AbstractMetaDataBuilderEJB
 {
-
    /** Logger. */
    protected final Logger log = Logger.getLogger(this.getClass());
 
    /**
     * Builds universal EJB meta data model that is AS agnostic.
-    * 
+    *
     * @param dep webservice deployment
     * @return universal EJB meta data model
     */
@@ -68,7 +67,7 @@
 
    /**
     * Template method for build enterprise beans meta data.
-    * 
+    *
     * @param dep webservice deployment
     * @param ejbMetaData universal EJB meta data model
     */
@@ -82,7 +81,7 @@
     *   <li>config name</li>
     *   <li>config file</li>
     * </ul>
-    * 
+    *
     * @param dep webservice deployment
     * @param ejbArchiveMD universal EJB meta data model
     */
@@ -151,5 +150,4 @@
 
       return false;
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/metadata/ContainerMetaDataDeploymentAspect.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/metadata/ContainerMetaDataDeploymentAspect.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/metadata/ContainerMetaDataDeploymentAspect.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -35,7 +35,6 @@
  */
 public final class ContainerMetaDataDeploymentAspect extends AbstractDeploymentAspect
 {
-
    /** JSE meta data builder. */
    private final MetaDataBuilderJSE metaDataBuilderJSE = new MetaDataBuilderJSE();
 
@@ -55,7 +54,7 @@
 
    /**
     * Build container independent meta data.
-    * 
+    *
     * @param dep webservice deployment
     */
    @Override
@@ -80,5 +79,4 @@
          dep.addAttachment(EJBArchiveMetaData.class, ejbMetaData);
       }
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/metadata/MetaDataBuilderEJB21.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/metadata/MetaDataBuilderEJB21.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/metadata/MetaDataBuilderEJB21.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -45,7 +45,6 @@
  */
 final class MetaDataBuilderEJB21 extends AbstractMetaDataBuilderEJB
 {
-
    /**
     * Constructor.
     */
@@ -80,7 +79,7 @@
 
    /**
     * Builds JBoss agnostic EJB meta data.
-    * 
+    *
     * @param wsEjbsMD jboss agnostic EJBs meta data
     * @param jbossEjbMD jboss specific EJB meta data
     */
@@ -154,5 +153,4 @@
 
       return null;
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/metadata/MetaDataBuilderEJB3.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/metadata/MetaDataBuilderEJB3.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/metadata/MetaDataBuilderEJB3.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -46,7 +46,6 @@
  */
 final class MetaDataBuilderEJB3 extends AbstractMetaDataBuilderEJB
 {
-
    /**
     * Constructor.
     */
@@ -57,7 +56,7 @@
 
    /**
     * @see AbstractMetaDataBuilderEJB#buildEnterpriseBeansMetaData(Deployment, EJBArchiveMetaData)
-    * 
+    *
     * @param dep webservice deployment
     * @param ejbArchiveMD EJB archive meta data
     */
@@ -77,7 +76,7 @@
 
    /**
     * Builds JBoss agnostic EJB meta data.
-    * 
+    *
     * @param wsEjbsMD jboss agnostic EJBs meta data
     * @param jbossEjbMD jboss specific EJB meta data
     */
@@ -142,7 +141,7 @@
 
    /**
     * Returns activation config property value or null if not found.
-    * 
+    *
     * @param name activation property name
     * @param activationConfigProperties activation config properties
     * @return activation config property value
@@ -162,5 +161,4 @@
 
       return null;
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/metadata/MetaDataBuilderJSE.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/metadata/MetaDataBuilderJSE.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/metadata/MetaDataBuilderJSE.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -51,14 +51,13 @@
 import org.jboss.wsf.spi.metadata.j2ee.PublishLocationAdapter;
 
 /**
- * Builds container independent meta data from WEB container meta data. 
+ * Builds container independent meta data from WEB container meta data.
  *
  * @author <a href="mailto:ropalka at redhat.com">Richard Opalka</a>
  * @author <a href="mailto:tdiesler at redhat.com">Thomas Diesler</a>
  */
 final class MetaDataBuilderJSE
 {
-
    /** Logger. */
    private final Logger log = Logger.getLogger(MetaDataBuilderJSE.class);
 
@@ -72,7 +71,7 @@
 
    /**
     * Builds universal JSE meta data model that is AS agnostic.
-    * 
+    *
     * @param dep webservice deployment
     * @return universal JSE meta data model
     */
@@ -152,7 +151,7 @@
 
    /**
     * Builds security meta data.
-    * 
+    *
     * @param securityConstraintsMD security constraints meta data
     * @return universal JSE security meta data model
     */
@@ -181,7 +180,7 @@
 
    /**
     * Sets web resources in universal meta data model.
-    * 
+    *
     * @param jseSecurityMD universal JSE security meta data model
     * @param securityConstraintMD security constraint meta data
     */
@@ -203,7 +202,7 @@
 
    /**
     * Returns servlet name to url pattern mappings.
-    * 
+    *
     * @param jbossWebMD jboss web meta data
     * @return servlet name to url pattern mappings
     */
@@ -225,7 +224,7 @@
 
    /**
     * Returns servlet name to servlet class mappings.
-    * 
+    *
     * @param jbossWebMD jboss web meta data
     * @return servlet name to servlet mappings
     */
@@ -258,7 +257,7 @@
     * If there's application.xml descriptor provided defining nested web module,
     * then context root defined there will be returned. 
     * Otherwise context root defined in jboss-web.xml will be returned.
-    * 
+    *
     * @param dep webservice deployment
     * @param jbossWebMD jboss web meta data
     * @return context root
@@ -284,5 +283,4 @@
       // prefer context root defined in application.xml over one defined in jboss-web.xml
       return contextRoot != null ? contextRoot : jbossWebMD.getContextRoot();
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/metadata/PublishLocationAdapterImpl.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/metadata/PublishLocationAdapterImpl.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/metadata/PublishLocationAdapterImpl.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -33,13 +33,12 @@
  */
 final class PublishLocationAdapterImpl implements PublishLocationAdapter
 {
-
    /** Webservice descriptions meta data. */
    private final WebserviceDescriptionsMetaData wsDescriptionsMD;
 
    /**
     * Constructor.
-    * 
+    *
     * @param wsDescriptionsMD webservice descriptions meta data
     */
    PublishLocationAdapterImpl(final WebserviceDescriptionsMetaData wsDescriptionsMD)
@@ -51,7 +50,7 @@
 
    /**
     * @see org.jboss.wsf.spi.metadata.j2ee.PublishLocationAdapter#getWsdlPublishLocationByName(String)
-    * 
+    *
     * @param endpointName endpoint name
     * @return publish location
     */
@@ -69,5 +68,4 @@
 
       return null;
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/security/JACCPermissionsDeploymentAspect.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/security/JACCPermissionsDeploymentAspect.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/security/JACCPermissionsDeploymentAspect.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -31,17 +31,16 @@
 import org.jboss.wsf.common.integration.AbstractDeploymentAspect;
 
 /**
- * Generates JACC permissions. (This is temporary and really hacky solution). 
- * 
- * TODO: remove this deployment aspect and update 
- * particular JACC deployer to execute after 
- * JBossWS has modified web meta data. 
+ * Generates JACC permissions. (This is temporary and really hacky solution).
  *
+ * TODO: remove this deployment aspect and update
+ * particular JACC deployer to execute after
+ * JBossWS has modified web meta data.
+ *
  * @author <a href="mailto:ropalka at redhat.com">Richard Opalka</a>
  */
 public final class JACCPermissionsDeploymentAspect extends AbstractDeploymentAspect
 {
-
    /**
     * Constructor.
     */
@@ -55,7 +54,7 @@
     * does not go through the war security deployer. Hence the JACC
     * permissions are not created. There is a need to explicitly create
     * the war jacc permissions.
-    * 
+    *
     * @param dep webservice deployment
     */
    @Override
@@ -78,5 +77,4 @@
          throw new RuntimeException("Exception generating JACC perms: ", e);
       }
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/security/SecurityAdapterFactoryImpl.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/security/SecurityAdapterFactoryImpl.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/security/SecurityAdapterFactoryImpl.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -26,13 +26,12 @@
 
 /**
  * Security adapters factory.
- * 
+ *
  * @author <a href="mailto:ropalka at redhat.com">Richard Opalka</a>
  * @author <a href="mailto:tdiesler at redhat.com">Thomas Diesler</a>
  */
 public final class SecurityAdapterFactoryImpl extends SecurityAdaptorFactory
 {
-
    /**
     * Constructor.
     */
@@ -43,12 +42,11 @@
 
    /**
     * Creates new security adapter instance.
-    * 
+    *
     * @return security adapter
     */
    public SecurityAdaptor newSecurityAdapter()
    {
       return new SecurityAdapterImpl();
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/security/SecurityAdapterImpl.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/security/SecurityAdapterImpl.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/security/SecurityAdapterImpl.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -40,7 +40,6 @@
  */
 final class SecurityAdapterImpl implements SecurityAdaptor
 {
-
    /**
     * Constructor.
     */
@@ -51,7 +50,7 @@
 
    /**
     * @see org.jboss.wsf.spi.invocation.SecurityAdaptor#getPrincipal()
-    * 
+    *
     * @return principal
     */
    public Principal getPrincipal()
@@ -61,7 +60,7 @@
 
    /**
     * @see org.jboss.wsf.spi.invocation.SecurityAdaptor#setPrincipal(Principal)
-    * 
+    *
     * @param principal principal
     */
    public void setPrincipal(final Principal principal)
@@ -71,7 +70,7 @@
 
    /**
     * @see org.jboss.wsf.spi.invocation.SecurityAdaptor#getCredential()
-    * 
+    *
     * @return credential
     */
    public Object getCredential()
@@ -81,7 +80,7 @@
 
    /**
     * @see org.jboss.wsf.spi.invocation.SecurityAdaptor#setCredential(Object)
-    *  
+    *
     * @param credential credential
     */
    public void setCredential(final Object credential)
@@ -91,7 +90,7 @@
 
    /**
     * @see org.jboss.wsf.spi.invocation.SecurityAdaptor#pushSubjectContext(Subject, Principal, Object)
-    * 
+    *
     * @param subject subject
     * @param principal principal
     * @param credential credential
@@ -115,5 +114,4 @@
          }
       });
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/tomcat/AbstractSecurityMetaDataAccessorEJB.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/tomcat/AbstractSecurityMetaDataAccessorEJB.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/tomcat/AbstractSecurityMetaDataAccessorEJB.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -36,7 +36,6 @@
  */
 abstract class AbstractSecurityMetaDataAccessorEJB implements SecurityMetaDataAccessorEJB
 {
-
    /** JAAS JNDI prefix. */
    private static final String JAAS_JNDI_PREFIX = "java:/jaas/";
 
@@ -126,5 +125,4 @@
 
       return ejbMD != null ? ejbMD.getSecurityMetaData() : null;
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/tomcat/SecurityMetaDataAccessorEJB.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/tomcat/SecurityMetaDataAccessorEJB.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/tomcat/SecurityMetaDataAccessorEJB.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -33,7 +33,6 @@
  */
 interface SecurityMetaDataAccessorEJB
 {
-
    /**
     * Obtains security domain from EJB deployment.
     *
@@ -73,5 +72,4 @@
     * @return transport guarantee or null if not specified
     */
    String getTransportGuarantee(Endpoint endpoint);
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/tomcat/SecurityMetaDataAccessorEJB21.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/tomcat/SecurityMetaDataAccessorEJB21.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/tomcat/SecurityMetaDataAccessorEJB21.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -29,14 +29,13 @@
 import org.jboss.wsf.spi.metadata.j2ee.EJBArchiveMetaData;
 
 /**
- * Creates web app security meta data for EJB 21 deployment. 
+ * Creates web app security meta data for EJB 21 deployment.
  *
  * @author <a href="mailto:ropalka at redhat.com">Richard Opalka</a>
  * @author <a href="mailto:tdiesler at redhat.com">Thomas Diesler</a>
  */
 final class SecurityMetaDataAccessorEJB21 extends AbstractSecurityMetaDataAccessorEJB
 {
-
    /**
     * Constructor.
     */
@@ -71,5 +70,4 @@
 
       return (assemblyDescriptorMD != null) ? assemblyDescriptorMD.getSecurityRoles() : null;
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/tomcat/SecurityMetaDataAccessorEJB3.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/tomcat/SecurityMetaDataAccessorEJB3.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/tomcat/SecurityMetaDataAccessorEJB3.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -43,7 +43,6 @@
  */
 final class SecurityMetaDataAccessorEJB3 extends AbstractSecurityMetaDataAccessorEJB
 {
-
    /**
     * Constructor.
     */
@@ -152,8 +151,8 @@
 
    /**
     * Gets <b>WebContext</b> if associated with EJB endpoint.
-    * 
-    * @param endpoint EJB webservice endpoint 
+    *
+    * @param endpoint EJB webservice endpoint
     * @return web context associated with EJB or null
     */
    @SuppressWarnings(
@@ -208,5 +207,4 @@
          throw new IllegalStateException(errorMessage + firstDomain + secondDomain);
       }
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/tomcat/WebMetaDataCreatingDeploymentAspect.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/tomcat/WebMetaDataCreatingDeploymentAspect.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/tomcat/WebMetaDataCreatingDeploymentAspect.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -26,14 +26,13 @@
 import org.jboss.wsf.common.integration.AbstractDeploymentAspect;
 
 /**
- * A deployment aspect that generates web app meta data for EJB endpoints. 
+ * A deployment aspect that generates web app meta data for EJB endpoints.
  *
  * @author <a href="mailto:ropalka at redhat.com">Richard Opalka</a>
  * @author <a href="mailto:tdiesler at redhat.com">Thomas Diesler</a>
  */
 public final class WebMetaDataCreatingDeploymentAspect extends AbstractDeploymentAspect
 {
-
    /** Web meta data creator. */
    private WebMetaDataCreator webMetaDataCreator = new WebMetaDataCreator();
 
@@ -61,5 +60,4 @@
          this.webMetaDataCreator.create(dep);
       }
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/tomcat/WebMetaDataCreator.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/tomcat/WebMetaDataCreator.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/tomcat/WebMetaDataCreator.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -46,7 +46,6 @@
  */
 final class WebMetaDataCreator
 {
-
    /** Our Realm. */
    private static final String EJB_WEBSERVICE_REALM = "EJBWebServiceEndpointServlet Realm";
 
@@ -78,7 +77,7 @@
       JBossWebMetaData jbossWebMD = ASHelper.getOptionalAttachment(unit, JBossWebMetaData.class);
       if (jbossWebMD == null)
       {
-    	 jbossWebMD = new JBossWebMetaData();
+         jbossWebMD = new JBossWebMetaData();
       }
 
       this.createWebAppDescriptor(dep, jbossWebMD);
@@ -368,5 +367,4 @@
 
       return isJaxws ? this.ejb3SecurityAccessor : this.ejb21SecurityAccessor;
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/tomcat/WebMetaDataModifier.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/tomcat/WebMetaDataModifier.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/tomcat/WebMetaDataModifier.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -45,7 +45,6 @@
  */
 final class WebMetaDataModifier
 {
-
    /** Logger. */
    private final Logger log = Logger.getLogger(WebMetaDataModifier.class);
 
@@ -123,7 +122,7 @@
    private String getTransportClassName(final Deployment dep)
    {
       String transportClassName = null;
-      String transportClassProviderName = (String) dep.getProperty("stack.transport.class.provider"); //TODO replace with WSContants reference once jbossws-common 1.4 is released
+      String transportClassProviderName = (String) dep.getProperty(WSConstants.STACK_TRANSPORT_CLASS_PROVIDER);
       if (transportClassProviderName != null)
       {
          try
@@ -133,10 +132,10 @@
          }
          catch (Exception e)
          {
-            log.warn("Cannot get transport class name from stack.transport.class.provider", e);
+            log.warn("Cannot get transport class name from " + WSConstants.STACK_TRANSPORT_CLASS_PROVIDER, e);
          }
       }
-      
+
       if (transportClassName == null)
       {
          transportClassName = (String) dep.getProperty(WSConstants.STACK_TRANSPORT_CLASS);
@@ -149,5 +148,4 @@
 
       return transportClassName;
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/tomcat/WebMetaDataModifyingDeploymentAspect.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/tomcat/WebMetaDataModifyingDeploymentAspect.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/tomcat/WebMetaDataModifyingDeploymentAspect.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -32,7 +32,6 @@
  */
 public final class WebMetaDataModifyingDeploymentAspect extends AbstractDeploymentAspect
 {
-
    /** Web meta data modifier. */
    private WebMetaDataModifier webMetaDataModifier = new WebMetaDataModifier();
 
@@ -55,5 +54,4 @@
       this.log.debug("Modifying web meta data for webservice deployment: " + dep.getSimpleName());
       this.webMetaDataModifier.modify(dep);
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/util/ASHelper.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/util/ASHelper.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/util/ASHelper.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -47,8 +47,7 @@
  */
 public final class ASHelper
 {
-
-   /** 
+   /**
     * EJB invocation property.
     */
    public static final String CONTAINER_NAME = "org.jboss.wsf.spi.invocation.ContainerName";
@@ -231,7 +230,7 @@
 
    /**
     * Returns true if EJB container is webservice endpoint.
-    * 
+    *
     * @param ejbContainerAdapter EJB container adapter
     * @return true if EJB container is webservice endpoint, false otherwise
     */
@@ -258,7 +257,7 @@
 
    /**
     * Returns servlet meta data for requested servlet name.
-    * 
+    *
     * @param jbossWebMD jboss web meta data
     * @param servletName servlet name
     * @return servlet meta data
@@ -310,12 +309,12 @@
    }
 
    /**
-    * Returns required attachment value from deployment unit. 
-    * 
+    * Returns required attachment value from deployment unit.
+    *
     * @param <A> expected value
     * @param unit deployment unit
     * @param key attachment key
-    * @return required attachment 
+    * @return required attachment
     * @throws IllegalStateException if attachment value is null
     */
    public static <A> A getRequiredAttachment(final DeploymentUnit unit, final Class<A> key)
@@ -332,11 +331,11 @@
 
    /**
     * Returns optional attachment value from deployment unit or null if not bound.
-    * 
+    *
     * @param <A> expected value
     * @param unit deployment unit
     * @param key attachment key
-    * @return optional attachment value or null 
+    * @return optional attachment value or null
     */
    public static <A> A getOptionalAttachment(final DeploymentUnit unit, final Class<A> key)
    {
@@ -345,7 +344,7 @@
 
    /**
     * Returns true if deployment unit have attachment value associated with the <b>key</b>.
-    *  
+    *
     * @param unit deployment unit
     * @param key attachment key
     * @return true if contains attachment, false otherwise
@@ -415,5 +414,4 @@
 
       return endpoints;
    }
-
 }

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/util/WebMetaDataHelper.java
===================================================================
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/util/WebMetaDataHelper.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/util/WebMetaDataHelper.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -47,7 +47,6 @@
  */
 public final class WebMetaDataHelper
 {
-
    /** Star utility string. */
    private static final String STAR_STRING = "*";
 
@@ -420,5 +419,4 @@
 
       return paramMD;
    }
-
 }

Modified: trunk/webservices/src/resources/jbossws-jboss.deployer/META-INF/stack-agnostic-jboss-beans.xml
===================================================================
--- trunk/webservices/src/resources/jbossws-jboss.deployer/META-INF/stack-agnostic-jboss-beans.xml	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/resources/jbossws-jboss.deployer/META-INF/stack-agnostic-jboss-beans.xml	2010-10-08 07:38:48 UTC (rev 108484)
@@ -41,12 +41,21 @@
     -->
   </bean>
 
+  <!-- stack agnostic webservices.xml processor -->
+  <bean name="WSDescriptorProcessor" class="org.jboss.wsf.framework.deployment.jms.WebservicesDescriptorProcessorImpl">
+    <property name="validating">true</property>
+    <property name="descriptorName">webservices.xml</property>
+  </bean>
+
   <!-- deployers -->
   <bean name="WSDescriptorDeployer" class="org.jboss.webservices.integration.deployers.WSDescriptorDeployer">
-    <property name="name">webservices.xml</property>
-    <property name="useSchemaValidation">true</property>
+    <incallback method="setProcessor"/>
   </bean>
-
+  
+  <bean name="JMSDescriptorDeployer" class="org.jboss.webservices.integration.deployers.JMSDescriptorDeployer">
+    <incallback method="setProcessor"/>
+  </bean>
+  
   <bean name="WSEJBAdapterDeployer" class="org.jboss.webservices.integration.deployers.WSEJBAdapterDeployer"/>
 
   <bean name="WSTypeDeployer" class="org.jboss.webservices.integration.deployers.WSTypeDeployer"/>



More information about the jboss-cvs-commits mailing list
--- trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/deployment/AbstractDeploymentModelBuilder.java	2010-10-07 19:06:11 UTC (rev 108483)
+++ trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/deployment/AbstractDeploymentModelBuilder.java	2010-10-08 07:38:48 UTC (rev 108484)
@@ -30,7 +30,6 @@
  */
 abstract class AbstractDeploymentModelBuilder implements DeploymentModelBuilder
 {
-
    /** WSDL, XSD and XML files filter. */
    private static final WSVirtualFileFilter WS_FILE_FILTER = new WSVirtualFileFilter();
 
@@ -76,14 +75,14 @@
    protected abstract void build(Deployment dep, DeploymentUnit unit);
 
    /**
     * Creates new Web Service endpoint.
     *
     * @param endpointClass endpoint class name
     * @param endpointName endpoint name
     * @param dep deployment
     * @return WS endpoint
     */
-   protected final Endpoint newEndpoint(final String endpointClass, final String endpointName, final Deployment dep)
+   protected final Endpoint newHttpEndpoint(final String endpointClass, final String endpointName, final Deployment dep)
    {
       if (endpointName == null)
       {
@@ -95,7 +94,7 @@
          throw new NullPointerException("Null endpoint class");
       }
 
-      final Endpoint endpoint = this.deploymentModelFactory.newEndpoint(endpointClass);
+      final Endpoint endpoint = this.deploymentModelFactory.newHttpEndpoint(endpointClass);
       endpoint.setShortName(endpointName);
       dep.getService().addEndpoint(endpoint);
 
@@ -103,6 +102,33 @@
    }
 
    /**
+    * Creates new JMS Web Service endpoint.
+    *
+    * @param endpointClass endpoint class name
+    * @param endpointName endpoint name
+    * @param dep deployment
+    * @return WS endpoint
+    */
+   protected final Endpoint newJMSEndpoint(final String endpointClass, final String endpointName, final Deployment dep)
+   {
+      if (endpointName == null)
+      {
+         throw new NullPointerException("Null endpoint name");
+      }
+
+      if (endpointClass == null)
+      {
+         throw new NullPointerException("Null endpoint class");
+      }
+
+      final Endpoint endpoint = this.deploymentModelFactory.newJMSEndpoint(endpointClass);
+      endpoint.setShortName(endpointName);
+      dep.getService().addEndpoint(endpoint);
+
+      return endpoint;
+   }
+
+   /**
     * Creates new Web Service deployment.
     *
     * @param unit deployment unit
@@ -187,5 +213,4 @@
 
       throw new IllegalStateException("Deployment unit does not contain " + attachment);
    }
-
 }
@@ -76,14 +75,14 @@
 
    /**
-    * Creates new Web Service endpoint.
+    * Creates new Http Web Service endpoint.
     *
     * @param endpointClass endpoint class name

Modified: trunk/webservices/src/main/java/org/jboss/webservices/integration/deployers/deployment/DeploymentModelBuilder.java
===================================================================